@@ -1,5 +1,5 @@
 package Net::Cisco::FMC::v1;
-$Net::Cisco::FMC::v1::VERSION = '0.009000';
+$Net::Cisco::FMC::v1::VERSION = '0.009001';
 # ABSTRACT: Cisco Firepower Management Center (FMC) API version 1 client library
 
 use 5.024;
@@ -334,10 +334,6 @@ sub get_accessrule ($self, $accesspolicy_id, $id, $query_params = {}) {
 
 sub update_accessrule ($self, $accesspolicy_id, $object, $object_data, $query_params = {}) {
     my $id = $object->{id};
-    my $fmc_rule = clone($object);
-    for my $user ($fmc_rule->{users}->{objects}->@*) {
-        delete $user->{realm};
-    }
     return $self->_update(join('/',
         '/api/fmc_config/v1/domain',
         $self->domain_uuid,
@@ -346,7 +342,7 @@ sub update_accessrule ($self, $accesspolicy_id, $object, $object_data, $query_pa
         $accesspolicy_id,
         'accessrules',
         $id
-    ), $fmc_rule, $object_data, $query_params);
+    ), $object, $object_data, $query_params);
 }
 
 
@@ -725,7 +721,7 @@ Net::Cisco::FMC::v1 - Cisco Firepower Management Center (FMC) API version 1 clie
 
 =head1 VERSION
 
-version 0.009000
+version 0.009001
 
 =head1 SYNOPSIS
 
